@@ -7,6 +7,8 @@
 #include <QObject>
 #include <QGeoPositionInfoSourceFactory>
 
+QT_BEGIN_NAMESPACE
+
 class QGeoPositionInfoSourceFactoryCL : public QObject, public QGeoPositionInfoSourceFactory
 {
     Q_OBJECT
@@ -19,4 +21,6 @@ public:
     QGeoAreaMonitorSource *areaMonitor(QObject *parent, const QVariantMap &parameters) override;
 };
 
+QT_END_NAMESPACE
+
 #endif // QGEOPOSITIONINFOSOURCEFACTORY_CL_H
